#
# spec file for package forgejo-runner
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define services %{name}.service

Name:           forgejo-runner
Version:        6.3.1
Release:        1.1
Summary:        Daemon that connects to a Forgejo instance and runs CI jobs
License:        MIT
URL:            https://code.forgejo.org/forgejo/runner
Source0:        %{name}-%{version}.tar.gz
Source1:        vendor.tar.gz
Source2:        %{name}.service
Patch0:         fix-CVE-2025-22869.patch
BuildRequires:  bash-completion
BuildRequires:  fish
BuildRequires:  zsh
BuildRequires:  golang(API) >= 1.23
BuildRequires:  pkgconfig(systemd)
Requires:       (podman or docker)
%{?systemd_ordering}

%description
A daemon that connects to a Forgejo instance and runs jobs for continous
integration. The installation and usage instructions are part of the Forgejo
documentation.
https://forgejo.org/docs/next/admin/actions/

%package -n %{name}-bash-completion
Summary:        Bash Completion for %{name}
Group:          System/Shells
Requires:       %{name} = %{version}
Requires:       bash-completion
Supplements:    (%{name} and bash-completion)
BuildArch:      noarch

%description -n %{name}-bash-completion
Bash command line completion support for %{name}.

%package -n %{name}-fish-completion
Summary:        Fish Completion for %{name}
Group:          System/Shells
Requires:       %{name} = %{version}
Supplements:    (%{name} and fish)
BuildArch:      noarch

%description -n %{name}-fish-completion
Fish command line completion support for %{name}.

%package -n %{name}-zsh-completion
Summary:        Zsh Completion for %{name}
Group:          System/Shells
Requires:       %{name} = %{version}
Supplements:    (%{name} and zsh)
BuildArch:      noarch

%description -n %{name}-zsh-completion
zsh command line completion support for %{name}.

%prep
%autosetup -a1

%build
go build \
   -mod=vendor \
   -buildmode=pie \
   -tags="netgo osusergo" \
   -ldflags="-X gitea.com/gitea/act_runner/internal/pkg/ver.version=v%{version}" \
   -o bin/%{name}

bin/%{name} generate-config > config.yaml

perl -p -i -e 's|file: \.runner|file: /etc/forgejo-runner/runners|g' config.yaml

%install
# Install the binary.
install -D -m 0755 bin/%{name} %{buildroot}/%{_bindir}/%{name}

# Install the service file.
install -D -m 0644 %{SOURCE2} %{buildroot}/%{_unitdir}/%{name}.service

# create the bash completion file
mkdir -p %{buildroot}%{_datarootdir}/bash-completion/completions/
%{buildroot}/%{_bindir}/%{name} completion bash > %{buildroot}%{_datarootdir}/bash-completion/completions/%{name}

# create the fish completion file
mkdir -p %{buildroot}%{_datarootdir}/fish/vendor_completions.d/
%{buildroot}/%{_bindir}/%{name} completion fish > %{buildroot}%{_datarootdir}/fish/vendor_completions.d/%{name}.fish

# create the zsh completion file
mkdir -p %{buildroot}%{_datadir}/zsh/site-functions/
%{buildroot}/%{_bindir}/%{name} completion zsh > %{buildroot}%{_datadir}/zsh/site-functions/%{name}

install -D -m 0750 -d          %{buildroot}%{_sysconfdir}/%{name}
install    -m 0640 config.yaml %{buildroot}%{_sysconfdir}/%{name}/config.yaml
install    -m 0640 /dev/null   %{buildroot}%{_sysconfdir}/%{name}/runners
install -D -m 0750 -d          %{buildroot}%{_localstatedir}/lib/%{name}

%check
bin/%{name} --version | grep %{version}

%pre
%service_add_pre %{services}

%preun
%service_del_preun %{services}

%post
%service_add_post %{services}

%postun
%service_del_postun %{services}

%files
%doc README.md
%license LICENSE
%{_bindir}/%{name}
%{_unitdir}/forgejo-runner.service
%config(noreplace) %{_sysconfdir}/%{name}
%dir %{_localstatedir}/lib/%{name}

%files -n %{name}-bash-completion
%{_datadir}/bash-completion/completions/%{name}

%files -n %{name}-fish-completion
%{_datadir}/fish/vendor_completions.d/%{name}.fish

%files -n %{name}-zsh-completion
%{_datadir}/zsh/site-functions/%{name}

%changelog
* Wed Mar 26 2025 rrahl0@opensuse.org
- Update to version 6.3.1:
  * Fixed an issue which caused data races and timeouts in certain cases, which
    would cause cache storing and retrieval to fail.
* Sat Mar 22 2025 rrahl0@opensuse.org
- Update to version 6.3.0:
  * Caches are now correctly scoped to repositories. Require authentication for
    cache requests, and set up cache proxy to provide authentication
    transparently and automatically.
* Wed Mar 12 2025 Richard Rahl <rrahl0@opensuse.org>
- add patch fix-CVE-2025-22869.patch, fixes bsc#1239488 bsc#1234574
* Mon Mar 10 2025 Marcus Rueckert <mrueckert@suse.de>
- also own the runners file
* Mon Mar 10 2025 Marcus Rueckert <mrueckert@suse.de>
- import config handling from the gitea-action-runner package
  the config can contain secrets and we should probably protect
  them with proper default permissions
* Mon Mar 10 2025 Marcus Rueckert <mrueckert@suse.de>
- not sure why this was installed as an user service
* Sat Feb  1 2025 rrahl0@opensuse.org
- Update to version 6.2.2:
  * LXC systemd service unit example script learned how to upgrade.
- update to version 6.2.1:
  * LXC templates are updated if needed.
* Thu Jan 23 2025 Richard Rahl <rrahl0@opensuse.org>
- update to 6.2.0:
  * The container.options allows --hostname.
* Wed Jan 22 2025 rrahl0@opensuse.org
- Update to version 6.1.0:
  * chore(release): migrate to invisible.forgejo.org (#444)
  * Update module google.golang.org/protobuf to v1.36.3 (#440)
  * Update actions/setup-forgejo action to v2.0.6
  * fix: upgrade forgejo-build-publish/build@v5.3.1
  * fix: use data.forgejo.org/oci
  * New "one shot" type of execution by adding a new command called one-job. (#423)
  * fix: example uses code.forgejo.org/oci
  * chore(docs): 6.1.0 release notes (#428)
  * expose "ForceRebuild" as a config option
* Sat Jan 18 2025 Richard Rahl <rrahl0@opensuse.org>
- update to 6.0.1:
  * Fixes a regression that was introduced in version 6.0.0 by which the
    [container].options config file setting was ignored.
- update to 6.0.0:
  * Security: the container options a job is allowed to specify are limited to
    a predefined allow list.
* Wed Dec 18 2024 rrahl0@opensuse.org
- Update to version 5.0.4:
  * feat: use FORGEJO_TOKEN as runtime token
* Wed Nov 27 2024 Richard Rahl <rrahl0@opensuse.org>
- update to 5.0.3:
  * fix: it wasn't possible to mount the docker socket in each container
* Thu Nov 21 2024 rrahl0@opensuse.org
- Update to version 5.0.2:
  * Fixes a regression that was introduced in version 5.0.0 by which
    skipped jobs were marked as failed instead
* Wed Nov 20 2024 rrahl0@opensuse.org
- Update to version 5.0.1:
  * the /opt/hostedtoolcache directory is now unique to each job instead of
    being shared to avoid a risk of corruption
- move to golang(API) = 1.23
* Sun Nov 17 2024 rrahl0@opensuse.org
- Update to version 5.0.0:
  * fix: Update forgejo/forgejo-build-publish action to v5
  * fix: make container.docker_host default to - (part two)
  * Update golang packages to v1.23
  * tests: it make take time for Forgejo to come up
  * Update code.forgejo.org/oci/alpine Docker tag to v3.20
  * ci: use `go-version-file`
  * Update actions/setup-go action to v5
  * ci: don't run on renovate branches
  * ci: Include version number in windows runner build
  * fix: dockerfile casing typo
  * Update module golang.org/x/time to v0.8.0
  * Update module golang.org/x/term to v0.26.0
  * Add support for windows build on GitHub (#312)
  * Update dependency go to v1.23.3
  * Version bump and add release notes
  * Cherry-pick gitea act_runner #543
  * Add simple test
  * Add configurable logging level for jobs
* Fri Nov  1 2024 rrahl0@opensuse.org
- Update to version 4.0.1:
  * Do not panic when the number of arguments of a function evaluated
    in an expression is incorect.
* Tue Oct 29 2024 rrahl0@opensuse.org
- Update to version 4.0.0:
  * fix: make container.docker_host default to -
  * Update module code.forgejo.org/forgejo/act to v1.21.4
  * chore: add issue templates
  * Update module golang.org/x/time to v0.7.0
  * Update module google.golang.org/protobuf to v1.35.1
  * Update module golang.org/x/term to v0.25.0
  * Update dependency go to v1.23.2
  * Update module connectrpc.com/connect to v1.17.0
  * Fix comments in systemd unit service file (#274)
  * Add example systemd service file (#273)
  * Update module code.forgejo.org/forgejo/act to v1.21.3
  * chore: update the 3.5.2 release notes
  * chore: add test for unexpected YAML type in top level env
  * Update dependency go to v1.23.1
  * Update module golang.org/x/term to v0.24.0
  * Fix typo
  * chore(renovate): disable replaced `nektos/act`
  * chore: update the DOER & TOKEN of the build release workflow
* Sun Aug 25 2024 rrahl0@opensuse.org
- Update to version 3.5.1:
  * Fix CVE-2024-24557
  * update vendored dependencies
* Mon Aug  5 2024 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- new package forgejo-runner: a daemon that connects to a Forgejo
  instance and runs jobs for continous integration
